
theme = {
    "style": "pastie",
    "title": {
        "fg": "#f20,bold,italics",
        "bg": "",
    },
    "author": {
        "fg": "#f20,bold",
        "bg": "",
    },
    "date": {
        "fg": "#222",
        "bg": "",
    },
    "slides": {
        "fg": "#f20,bold",
        "bg": "",
    },
    "quote": {
        "style": {
            "fg": "italics,#444",
            "bg":"default",
        },
    },
    "hrule": {
        "style": {
            "fg": "#555",
            "bg": "default",
        }
    },
    "link": {
        "fg": "#22f,underline,bold",
        "bg": "default",
    },
    "headings": {
        '1': {
          "fg": "#12c,bold",
          "bg": "default",
        },
        '2': {
          "fg": "#31c,bold",
          "bg": "default",
        },
        '3': {
          "fg": "#71c,bold",
          "bg": "default",
        },
        "4": {
          "fg": "#91c,bold",
          "bg": "default",
        },
        "default": {
          "fg": "#91c,bold",
          "bg": "default",
        },
    }
}
